{% extends "bootstrap/base.html" %}
{% set active_page = "about" %}
{% block head %}
	{{ super() }}
	<link rel="shortcut icon" href="{{ url_for('.static', filename='favicon.ico') }}">
{% endblock %}
{% block title %}About{% endblock %}

{% block content %}
{% include "navbar.html" %}

  <div class="container">
    <h1 class="page-header">About</h1>

    <h2>About This Application</h2>

    <p>
    This application was created using <i>Labeller</i>, see <a href="https://github.com/mdbloice/Labeller" target="_blank">https://github.com/mdbloice/Labeller</a> for details.
    </p>

    <h2>Feature Requests and Bugs</h2>

    <p>
      Create an issue for any feature requests, bugs found, etc. here: <a href="https://github.com/mdbloice/Labeller/issues" target="_blank">https://github.com/mdbloice/Labeller/issues</a>
    </p>

  </div>


{% include "footer.html" %}
{% endblock %}
